@@ -58,19 +58,17 @@ OFDMProcessor::OFDMProcessor(
         MscHandler& msc,
         FicHandler& fic,
         RadioReceiverOptions rro) :
+    receiver_options(rro),
     radioInterface(ri),
     input(inputInterface),
     params(params),
     ficHandler(fic),
-    decodeTII(rro.decodeTII),
     tiiDecoder(params, ri),
     T_null(params.T_null),
     T_u(params.T_u),
     T_s(params.T_s),
     T_F(params.T_F),
     oscillatorTable(INPUT_RATE),
-    disableCoarseCorrector(rro.disable_coarse_corrector),
-    freqsyncMethod(rro.freqsyncMethod),
     phaseRef(params, rro.fftPlacementMethod),
     ofdmDecoder(params, ri, fic, msc),
     fft_handler(params.T_u),
@@ -114,9 +112,15 @@ OFDMProcessor::~OFDMProcessor()
     }
 }
 
-void OFDMProcessor::start()
+void OFDMProcessor::restart()
 {
-    std::clog << "OFDM-processor:" <<  "start" << std::endl;
+    std::clog << "OFDM-processor:restart" << std::endl;
+
+    running = false;
+    if (threadHandle.joinable()) {
+        threadHandle.join();
+    }
+
     coarseCorrector    = 0;
     fineCorrector      = 0;
     syncBufferIndex    = 0;
@@ -230,20 +234,17 @@ void OFDMProcessor::getSamples(DSPCOMPLEX *v, int16_t n, int32_t phase)
  */
 void OFDMProcessor::run()
 {
-    int32_t     startIndex;
-    int32_t     i;
-    int32_t     counter;
-    float       currentStrength;
-    int32_t     syncBufferSize  = 32768;
-    int32_t     syncBufferMask  = syncBufferSize - 1;
-    float       envBuffer   [syncBufferSize];
+    int32_t startIndex;
+    int32_t i;
+    int32_t counter;
+    float currentStrength;
+    constexpr int32_t syncBufferSize  = 32768;
+    constexpr int32_t syncBufferMask  = syncBufferSize - 1;
+    float envBuffer[syncBufferSize];
 
     std::vector<DSPCOMPLEX> ofdmBuffer(params.L * params.T_s);
     std::vector<std::vector<DSPCOMPLEX> > allSymbols;
 
-    /*running       = true;
-      fineCorrector   = 0;
-      sLevel      = 0;*/
     try {
 
         //Initing:
@@ -372,8 +373,14 @@ SyncOnPhase:
                 T_u - ofdmBufferIndex,
                 coarseCorrector + fineCorrector);
 
+        RadioReceiverOptions rro;
+        {
+            std::lock_guard<std::mutex> lock(receiver_options_mutex);
+            rro = receiver_options;
+        }
+
         std::vector<complexf> prs;
-        if (decodeTII) {
+        if (rro.decodeTII) {
             prs.resize(T_u);
             std::copy(ofdmBuffer.begin(), ofdmBuffer.begin() + T_u, prs.begin());
         }
@@ -387,13 +394,13 @@ SyncOnPhase:
         //  reception glitch might provoke a long delay until it resyncs properly.
         //  As long as some FICs have correct CRC, we assume the coarse corrector cannot
         //  be off.
-        if (!disableCoarseCorrector and ficHandler.getFicDecodeRatioPercent() < 50) {
+        if (!rro.disableCoarseCorrector and ficHandler.getFicDecodeRatioPercent() < 50) {
             if (!coarseSyncCounter) {
                 std::clog << "ofdm-processor: " << "Lost coarse sync (coarseCorrector: " << lastValidCoarseCorrector << "; fineCorrector: " <<  lastValidFineCorrector << ")" << std::endl;
             }
 
             coarseSyncCounter++;
-            int correction = processPRS(ofdmBuffer.data());
+            int correction = processPRS(ofdmBuffer.data(), rro.freqsyncMethod);
             if (correction != 100) {
                 coarseCorrector += correction * params.carrierDiff;
                 if (abs (coarseCorrector) > kHz(35))
@@ -454,7 +461,7 @@ SyncOnPhase:
         // The NULL is interesting to save because it carries the TII.
         std::vector<DSPCOMPLEX> nullSymbol(T_null);
         getSamples(nullSymbol.data(), T_null, coarseCorrector + fineCorrector);
-        if (decodeTII) {
+        if (rro.decodeTII) {
             tiiDecoder.pushSymbols(nullSymbol, prs);
         }
 
@@ -487,24 +494,20 @@ SyncOnPhase:
     }
     catch (const InputFailure&) {
         std::clog << "OFDM-processor: input not ok, closing down" << std::endl;
+        running = false; //Needed before onInputFailure, because subsequent calls will call OFDMProcessor::stop()
         radioInterface.onInputFailure();
     }
     running = false;
 }
 
-void OFDMProcessor::reset()
-{
-    std::clog << "OFDM-processor: reset (" << running << ")" << std::endl;
-    if (running) {
-        running = false;
-        threadHandle.join();
-    }
-    start();
-}
-
 void OFDMProcessor::stop()
 {
-    running = false;
+    if (running) {
+        running = false;
+        if (threadHandle.joinable()) {
+            threadHandle.join();
+        }
+    }
 }
 
 void OFDMProcessor::resetCoarseCorrector()
@@ -514,15 +517,14 @@ void OFDMProcessor::resetCoarseCorrector()
 
 void OFDMProcessor::setReceiverOptions(const RadioReceiverOptions rro)
 {
-    bool need_reset = (disableCoarseCorrector != rro.disable_coarse_corrector);
-
-    decodeTII = rro.decodeTII;
-    disableCoarseCorrector = rro.disable_coarse_corrector;
-    freqsyncMethod = rro.freqsyncMethod;
+    std::unique_lock<std::mutex> lock(receiver_options_mutex);
+    bool need_reset = (receiver_options.disableCoarseCorrector != rro.disableCoarseCorrector);
+    receiver_options = rro;
     phaseRef.selectFFTWindowPlacement(rro.fftPlacementMethod);
+    lock.unlock();
 
     if (need_reset) {
-        reset();
+        restart();
     }
 }
 
@@ -532,7 +534,7 @@ void OFDMProcessor::set_scanMode(bool b)
 }
 
 #define RANGE 36
-int16_t OFDMProcessor::processPRS(DSPCOMPLEX *v)
+int16_t OFDMProcessor::processPRS(DSPCOMPLEX *v, const FreqsyncMethod& freqsyncMethod)
 {
     int16_t i, j, index = 100;
 
