@@ -318,7 +318,7 @@ int32_t CRAWFile::readBuffer(uint8_t* data, int32_t length)
     return n & ~01;
 }
 
-int32_t CRAWFile::convertSamples(RingBufferBase<uint8_t>& Buffer, DSPCOMPLEX *V, int32_t size)
+int32_t CRAWFile::convertSamples(RingBuffer<uint8_t>& Buffer, DSPCOMPLEX *V, int32_t size)
 {
     // Native endianness complex<float> requires no conversion
     if (fileFormat == CRAWFileFormat::COMPLEXF) {
@@ -326,9 +326,9 @@ int32_t CRAWFile::convertSamples(RingBufferBase<uint8_t>& Buffer, DSPCOMPLEX *V,
         return amount / IQByteSize;
     }
 
-    uint8_t *temp = (uint8_t*)alloca((size_t)IQByteSize * (size_t)size * sizeof(uint8_t));
+    std::vector<uint8_t> temp((size_t)IQByteSize * (size_t)size);
 
-    int32_t amount = Buffer.getDataFromBuffer(temp, IQByteSize * size);
+    int32_t amount = Buffer.getDataFromBuffer(temp.data(), IQByteSize * size);
 
     // Unsigned 8-bit
     if (fileFormat == CRAWFileFormat::U8) {
