@@ -1,5 +1,5 @@
 /*
- *    Copyright (C) 2019
+ *    Copyright (C) 2020
  *    Matthias P. Braendli (matthias.braendli@mpb.li)
  *
  *    This file is part of the welle.io.
@@ -23,16 +23,38 @@
  *
  */
 
-#include <future>
-#include <array>
+#include "welle-cli/webradiointerface.h"
 #include <algorithm>
+#include <cmath>
+#include <complex>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <ctime>
+#include <errno.h>
+#include <future>
 #include <iomanip>
 #include <iostream>
 #include <regex>
-#include <sstream>
+#include <signal.h>
+#include <stdexcept>
+
+#if defined(_WIN32)
+ #include <winsock2.h>
+ #include <ws2tcpip.h>
+ #include <windows.h>
+#else
+ #include <sys/socket.h>
+#endif
+
 #include <utility>
-#include <cstdio>
-#include <errno.h>
+#include "Socket.h"
+#include "channels.h"
+#include "ofdm-decoder.h"
+#include "radio-receiver.h"
+#include "virtual_input.h"
+#include "welle-cli/jsonconvert.h"
+#include "welle-cli/webprogrammehandler.h"
 
 #ifdef __unix__
 # include <unistd.h>
@@ -44,9 +66,6 @@
 # endif
 #endif
 
-#include "welle-cli/webradiointerface.h"
-#include "libs/json.hpp"
-
 #ifndef MSG_NOSIGNAL
 #define MSG_NOSIGNAL 0
 #endif
@@ -85,12 +104,11 @@ static const char* http_contenttype_html =
 
 static const char* http_nocache = "Cache-Control: no-cache\r\n";
 
-template <int W>
-static string to_hex(uint32_t value)
+static string to_hex(uint32_t value, int width)
 {
     std::stringstream sidstream;
     sidstream << "0x" <<
-        std::setfill('0') << std::setw(W) <<
+        std::setfill('0') << std::setw(width) <<
         std::hex << value;
     return sidstream.str();
 }
@@ -149,6 +167,11 @@ WebRadioInterface::~WebRadioInterface()
     if (programme_handler_thread.joinable()) {
         programme_handler_thread.join();
     }
+
+    {
+        lock_guard<mutex> lock(rx_mut);
+        rx.reset();
+    }
 }
 
 class TuneFailed {};
@@ -194,22 +217,22 @@ void WebRadioInterface::check_decoders_required()
                         programmes_being_decoded[sid] = false;
                     }
                     else {
-                        cerr << "Stop playing 0x" << to_hex<4>(s.serviceId) <<
+                        cerr << "Stop playing 0x" << to_hex(s.serviceId, 4) <<
                             " failed" << endl;
                         throw TuneFailed();
                     }
                 }
             }
             catch (const out_of_range&) {
-                cerr << "Cannot tune to 0x" << to_hex<4>(s.serviceId) <<
+                cerr << "Cannot tune to 0x" << to_hex(s.serviceId, 4) <<
                     " because no handler exists!" << endl;
             }
         }
     }
     catch (const TuneFailed&) {
+        rx->restart_decoder();
         phs.clear();
         programmes_being_decoded.clear();
-        rx->restart_decoder();
         carousel_services_available.clear();
         carousel_services_active.clear();
     }
@@ -223,26 +246,25 @@ void WebRadioInterface::retune(const std::string& channel)
 
     auto freq = channels.getFrequency(channel);
     if (freq == 0) {
-        cerr << "Invalid channel: " << channel << endl;
+        cerr << "RETUNE Invalid channel: " << channel << endl;
         return;
     }
 
-    cerr << "Retune to " << freq << endl;
+    cerr << "RETUNE: Retune to " << freq << endl;
 
-    cerr << "Kill programme handler" << freq << endl;
     running = false;
     if (programme_handler_thread.joinable()) {
         programme_handler_thread.join();
     }
 
-    cerr << "Take ownership of RX" << endl;
+    cerr << "RETUNE Take ownership of RX" << endl;
     {
         unique_lock<mutex> lock(rx_mut);
         // Even though it would be ok for rx to be inexistent here,
         // we check to uncover errors.
         ASSERT_RX;
 
-        cerr << "Destroy RX" << endl;
+        cerr << "RETUNE Destroy RX" << endl;
         rx.reset();
 
         {
@@ -261,11 +283,11 @@ void WebRadioInterface::retune(const std::string& channel)
         }
         tiis.clear();
 
-        cerr << "Set frequency" << endl;
+        cerr << "RETUNE Set frequency" << endl;
         input.setFrequency(freq);
         input.reset(); // Clear buffer
 
-        cerr << "Restart RX" << endl;
+        cerr << "RETUNE Restart RX" << endl;
         rx = make_unique<RadioReceiver>(*this, input, rro);
         if (not rx) {
             throw runtime_error("Could not initialise RadioReceiver");
@@ -274,7 +296,7 @@ void WebRadioInterface::retune(const std::string& channel)
         time_rx_created = chrono::system_clock::now();
         rx->restart(false);
 
-        cerr << "Start programme handler" << endl;
+        cerr << "RETUNE Start programme handler" << endl;
         running = true;
         programme_handler_thread = thread(&WebRadioInterface::handle_phs, this);
     }
@@ -363,7 +385,7 @@ static http_request_t parse_http_headers(Socket& s) {
     const auto request_type = split(first_line);
 
     if (request_type.size() != 3) {
-        cerr << "Malformed request: " << first_line;
+        cerr << "Malformed request: " << first_line << endl;
         return r;
     }
     else if (request_type[0] == "GET") {
@@ -398,7 +420,7 @@ static http_request_t parse_http_headers(Socket& s) {
             try {
                 const int content_length = std::stoi(r.headers[CL]);
                 if (content_length > 1024 * 1024) {
-                    cerr << "Unreasonable POST Content-Length: " << content_length;
+                    cerr << "Unreasonable POST Content-Length: " << content_length << endl;
                     return r;
                 }
 
@@ -406,11 +428,11 @@ static http_request_t parse_http_headers(Socket& s) {
                 r.post_data = string(buf.begin(), buf.end());
             }
             catch (const invalid_argument&) {
-                cerr << "Cannot parse POST Content-Length: " << r.headers[CL];
+                cerr << "Cannot parse POST Content-Length: " << r.headers[CL] << endl;
                 return r;
             }
             catch (const out_of_range&) {
-                cerr << "Cannot represent POST Content-Length: " << r.headers[CL];
+                cerr << "Cannot represent POST Content-Length: " << r.headers[CL] << endl;
                 return r;
             }
         }
@@ -547,23 +569,11 @@ bool WebRadioInterface::send_file(Socket& s,
     return false;
 }
 
-struct peak_t {
-    int index = -1;
-    float value = -1e30f;
-};
-
-static void to_json(nlohmann::json& j, const peak_t& peak)
-{
-    j = nlohmann::json{
-        {"index", peak.index},
-            {"value", 10.0f * log10(peak.value)}};
-}
-
-static nlohmann::json calculate_cir_peaks(const vector<float>& cir_linear)
+static vector<PeakJson> calculate_cir_peaks(const vector<float>& cir_linear)
 {
     constexpr size_t num_peaks = 6;
 
-    list<peak_t> peaks;
+    vector<PeakJson> peaks;
 
     if (not cir_linear.empty()) {
         vector<float> cir_lin(cir_linear);
@@ -571,7 +581,7 @@ static nlohmann::json calculate_cir_peaks(const vector<float>& cir_linear)
         // Every time we find a peak, we attenuate it, including
         // its surrounding values, and we go search the next peak.
         for (size_t peak = 0; peak < num_peaks; peak++) {
-            peak_t p;
+            PeakJson p;
             for (size_t i = 1; i < cir_lin.size(); i++) {
                 if (cir_lin[i] > p.value) {
                     p.value = cir_lin[i];
@@ -591,197 +601,144 @@ static nlohmann::json calculate_cir_peaks(const vector<float>& cir_linear)
         }
     }
 
-    nlohmann::json j = peaks;
-    return j;
-}
-
-static void set_label_json(nlohmann::json& j, const DabLabel& l)
-{
-    j["label"] = l.fig1_label_utf8();
-    j["shortlabel"] = l.fig1_shortlabel_utf8();
-    j["fig2label"] = l.fig2_label();
-    j["fig2rfu"] = l.fig2_rfu;
-    string extended_label_charset = "Unknown";
-    switch (l.extended_label_charset) {
-        case CharacterSet::EbuLatin: extended_label_charset = "EBU Latin (not allowed in FIG 2)"; break;
-        case CharacterSet::UnicodeUcs2: extended_label_charset = "UCS2"; break;
-        case CharacterSet::UnicodeUtf8: extended_label_charset = "UTF-8"; break;
-        case CharacterSet::Undefined: extended_label_charset = "Undefined"; break;
-    }
-    j["fig2charset"] = extended_label_charset;
+    return peaks;
 }
 
 bool WebRadioInterface::send_mux_json(Socket& s)
 {
-    nlohmann::json j;
+    MuxJson mux_json;
 
-    j["receiver"]["software"]["name"] = "welle.io";
-    j["receiver"]["software"]["version"] = VERSION;
-    j["receiver"]["software"]["fftwindowplacement"] = fftPlacementMethodToString(rro.fftPlacementMethod);
-    j["receiver"]["software"]["coarsecorrectorenabled"] = not rro.disable_coarse_corrector;
-    j["receiver"]["software"]["freqsyncmethod"] = freqSyncMethodToString(rro.freqsyncMethod);
-    j["receiver"]["software"]["lastchannelchange"] = chrono::system_clock::to_time_t(time_rx_created);
-    j["receiver"]["hardware"]["name"] = input.getDescription();
-    j["receiver"]["hardware"]["gain"] = input.getGain();
+    mux_json.receiver.software.name = "welle.io";
+    mux_json.receiver.software.version = VERSION;
+    mux_json.receiver.software.fftwindowplacement = fftPlacementMethodToString(rro.fftPlacementMethod);
+    mux_json.receiver.software.coarsecorrectorenabled = not rro.disableCoarseCorrector;
+    mux_json.receiver.software.freqsyncmethod = freqSyncMethodToString(rro.freqsyncMethod);
+    mux_json.receiver.software.lastchannelchange = chrono::system_clock::to_time_t(time_rx_created);
+    mux_json.receiver.hardware.name = input.getDescription();
+    mux_json.receiver.hardware.gain = input.getGain();
 
     {
         lock_guard<mutex> lock(fib_mut);
-        j["demodulator"]["fic"]["numcrcerrors"] = num_fic_crc_errors;
+        mux_json.demodulator_fic_numcrcerrors = num_fic_crc_errors;
     }
 
     {
         lock_guard<mutex> lock(rx_mut);
         ASSERT_RX;
-        const auto ensembleLabel = rx->getEnsembleLabel();
-        set_label_json(j["ensemble"], rx->getEnsembleLabel());
 
-        j["ensemble"]["id"] = to_hex<4>(rx->getEnsembleId());
-        j["ensemble"]["ecc"] = to_hex<2>(rx->getEnsembleEcc());
+        mux_json.ensemble.label = rx->getEnsembleLabel();
+
+        mux_json.ensemble.id = to_hex(rx->getEnsembleId(), 4);
+        mux_json.ensemble.ecc = to_hex(rx->getEnsembleEcc(), 2);
 
-        nlohmann::json j_services = nlohmann::json::array();
         for (const auto& s : rx->getServiceList()) {
-            nlohmann::json j_srv = {
-                {"sid", to_hex<4>(s.serviceId)},
-                {"pty", s.programType},
-                {"ptystring", DABConstants::getProgramTypeName(s.programType)},
-                {"language", s.language},
-                {"languagestring", DABConstants::getLanguageName(s.language)}};
+            ServiceJson service;
+            service.sid = to_hex(s.serviceId, 4);
+            service.programType = s.programType;
+            service.ptystring = DABConstants::getProgramTypeName(s.programType);
+            service.language = s.language;
+            service.languagestring = DABConstants::getLanguageName(s.language);
+            service.label = s.serviceLabel;
+            service.url_mp3 = "";
 
-            set_label_json(j_srv, s.serviceLabel);
-
-            nlohmann::json j_components;
-
-            bool hasAudioComponent = false;
             for (const auto& sc : rx->getComponents(s)) {
-                nlohmann::json j_sc = {
-                    {"componentnr", sc.componentNr},
-                    {"primary", (sc.PS_flag ? true : false)},
-                    {"caflag", (sc.CAflag ? true : false)},
-                    {"scid", nullptr},
-                    {"ascty", nullptr},
-                    {"dscty", nullptr}};
+                ComponentJson component;
+                component.componentnr = sc.componentNr;
+                component.primary = (sc.PS_flag ? true : false);
+                component.caflag = (sc.CAflag ? true : false);
+                component.label = sc.componentLabel;
 
-                set_label_json(j_sc, sc.componentLabel);
-
-                const auto& sub = rx->getSubchannel(sc);
+                const auto sub = rx->getSubchannel(sc);
 
                 switch (sc.transportMode()) {
                     case TransportMode::Audio:
-                        j_sc["transportmode"] = "audio";
-                        j_sc["ascty"] =
-                                (sc.audioType() == AudioServiceComponentType::DAB ? "DAB" :
-                                 sc.audioType() == AudioServiceComponentType::DABPlus ? "DAB+" :
-                                 "unknown");
-                        hasAudioComponent |= (
-                                sc.audioType() == AudioServiceComponentType::DAB or
-                                sc.audioType() == AudioServiceComponentType::DABPlus);
+                        component.transportmode = "audio";
+                        component.ascty = make_unique<string>(
+                                string{
+                                    (sc.audioType() == AudioServiceComponentType::DAB ? "DAB" :
+                                     sc.audioType() == AudioServiceComponentType::DABPlus ? "DAB+" :
+                                     "unknown")});
+                        if (sc.audioType() == AudioServiceComponentType::DAB or
+                            sc.audioType() == AudioServiceComponentType::DABPlus) {
+                            string urlmp3 = "/mp3/" + to_hex(s.serviceId, 4);
+                            service.url_mp3 = urlmp3;
+                        }
                         break;
                     case TransportMode::FIDC:
-                        j_sc["transportmode"] = "fidc";
-                        j_sc["dscty"] = sc.DSCTy;
+                        component.transportmode = "fidc";
+                        component.dscty = make_unique<uint16_t>(sc.DSCTy);
                         break;
                     case TransportMode::PacketData:
-                        j_sc["transportmode"] = "packetdata";
-                        j_sc["scid"] = sc.SCId;
+                        component.transportmode = "packetdata";
+                        component.scid = make_unique<uint16_t>(sc.SCId);
                         break;
                     case TransportMode::StreamData:
-                        j_sc["transportmode"] = "streamdata";
-                        j_sc["dscty"] = sc.DSCTy;
+                        component.transportmode = "streamdata";
+                        component.dscty = make_unique<uint16_t>(sc.DSCTy);
                         break;
                 }
 
-                j_sc["subchannel"] = {
-                    {"subchid", sub.subChId},
-                    {"bitrate", sub.bitrate()},
-                    {"cu", sub.numCU()},
-                    {"sad", sub.startAddr},
-                    {"protection", sub.protection()},
-                    {"language", sub.language},
-                    {"languagestring", DABConstants::getLanguageName(sub.language)}};
+                component.subchannel = sub;
 
-
-                j_components.push_back(j_sc);
+                service.components.push_back(move(component));
             }
 
-            if (hasAudioComponent) {
-                string urlmp3 = "/mp3/" + to_hex<4>(s.serviceId);
-                j_srv["url_mp3"] = urlmp3;
-            }
-            else {
-                j_srv["url_mp3"] = nullptr;
-            }
-
-            j_srv["components"] = j_components;
-
             try {
                 const auto& wph = phs.at(s.serviceId);
                 const auto al = wph.getAudioLevels();
-                nlohmann::json j_audio = {
-                    {"time", chrono::system_clock::to_time_t(al.time)},
-                    {"left", al.last_audioLevel_L},
-                    {"right", al.last_audioLevel_R}};
-                j_srv["audiolevel"] = j_audio;
+                service.audiolevel_present = true;
+                service.audiolevel_time = chrono::system_clock::to_time_t(al.time);
+                service.audiolevel_left = al.last_audioLevel_L;
+                service.audiolevel_right = al.last_audioLevel_R;
 
-                j_srv["channels"] = 2;
-                j_srv["samplerate"] = wph.rate;
-                j_srv["mode"] = wph.mode;
+                service.channels = 2;
+                service.samplerate = wph.rate;
+                service.mode = wph.mode;
 
                 auto mot = wph.getMOT();
-                nlohmann::json j_mot = {
-                    {"time", chrono::system_clock::to_time_t(mot.time)},
-                    {"lastchange", chrono::system_clock::to_time_t(mot.last_changed)}};
-                j_srv["mot"] = j_mot;
+                service.mot_time = chrono::system_clock::to_time_t(mot.time);
+                service.mot_lastchange = chrono::system_clock::to_time_t(mot.last_changed);
 
                 auto dls = wph.getDLS();
-                nlohmann::json j_dls = {
-                    {"label", dls.label},
-                    {"time", chrono::system_clock::to_time_t(dls.time)},
-                    {"lastchange", chrono::system_clock::to_time_t(mot.last_changed)}};
-                j_srv["dls"] = j_dls;
+                service.dls_label = dls.label;
+                service.dls_time = chrono::system_clock::to_time_t(dls.time);
+                service.dls_lastchange = chrono::system_clock::to_time_t(mot.last_changed);
 
                 auto errorcounters = wph.getErrorCounters();
-                nlohmann::json j_errorcounters = {
-                    {"frameerrors", errorcounters.num_frameErrors},
-                    {"rserrors", errorcounters.num_rsErrors},
-                    {"aacerrors", errorcounters.num_aacErrors},
-                    {"time", chrono::system_clock::to_time_t(dls.time)}};
-                j_srv["errorcounters"] = j_errorcounters;
+                service.errorcounters_frameerrors = errorcounters.num_frameErrors;
+                service.errorcounters_rserrors = errorcounters.num_rsErrors;
+                service.errorcounters_aacerrors = errorcounters.num_aacErrors;
+                service.errorcounters_time = chrono::system_clock::to_time_t(dls.time);
 
                 auto xpad_err = wph.getXPADErrors();
-                nlohmann::json j_xpad_err;
-                j_xpad_err["haserror"] = xpad_err.has_error;
+                service.xpaderror_haserror = xpad_err.has_error;
                 if (xpad_err.has_error) {
-                    j_xpad_err["announcedlen"] = xpad_err.announced_xpad_len;
-                    j_xpad_err["len"] = xpad_err.xpad_len;
-                    j_xpad_err["time"] = chrono::system_clock::to_time_t(xpad_err.time);
+                    service.xpaderror_announcedlen = xpad_err.announced_xpad_len;
+                    service.xpaderror_len = xpad_err.xpad_len;
+                    service.xpaderror_time = chrono::system_clock::to_time_t(xpad_err.time);
                 }
-                j_srv["xpaderror"] = j_xpad_err;
             }
             catch (const out_of_range&) {
-                j_srv["audiolevel"] = nullptr;
-                j_srv["channels"] = 0;
-                j_srv["samplerate"] = 0;
-                j_srv["mode"] = "invalid";
+                service.audiolevel_present = false;
+                service.channels = 0;
+                service.samplerate = 0;
+                service.mode = "invalid";
             }
 
-            j_services.push_back(j_srv);
+            mux_json.services.push_back(move(service));
         }
-        j["services"] = j_services;
     }
 
     {
         lock_guard<mutex> lock(data_mut);
 
-        nlohmann::json j_utc = {
-            {"year", last_dateTime.year},
-            {"month", last_dateTime.month},
-            {"day", last_dateTime.day},
-            {"hour", last_dateTime.hour},
-            {"minutes", last_dateTime.minutes},
-            {"lto", last_dateTime.hourOffset + ((double)last_dateTime.minuteOffset / 30.0)},
-        };
+        mux_json.utctime.year = last_dateTime.year;
+        mux_json.utctime.month = last_dateTime.month;
+        mux_json.utctime.day = last_dateTime.day;
+        mux_json.utctime.hour = last_dateTime.hour;
+        mux_json.utctime.minutes = last_dateTime.minutes;
+        mux_json.utctime.lto = last_dateTime.hourOffset + ((double)last_dateTime.minuteOffset / 30.0);
 
-        vector<string> msgs;
         for (const auto& m : pending_messages) {
             using namespace chrono;
 
@@ -806,38 +763,27 @@ bool WebRadioInterface::send_mux_json(Socket& s)
             }
 
             ss << m.text;
-            msgs.push_back(ss.str());
+            mux_json.messages.push_back(ss.str());
         }
 
         pending_messages.clear();
-        j["messages"] = msgs;
 
-        j["utctime"] = j_utc;
+        mux_json.demodulator_snr = last_snr;
+        mux_json.demodulator_frequencycorrection = last_fine_correction + last_coarse_correction;
 
-        j["demodulator"]["snr"] = last_snr;
-        j["demodulator"]["frequencycorrection"] =
-            last_fine_correction + last_coarse_correction;
-
-        for (const auto& tii : getTiiStats()) {
-            j["tii"].push_back({
-                    {"comb", tii.comb},
-                    {"pattern", tii.pattern},
-                    {"delay", tii.delay_samples},
-                    {"delay_km", tii.getDelayKm()},
-                    {"error", tii.error}});
-        }
+        mux_json.tii = getTiiStats();
     }
 
     {
         lock_guard<mutex> lock(plotdata_mut);
-        j["cir"] = calculate_cir_peaks(last_CIR);
+        mux_json.cir_peaks = calculate_cir_peaks(last_CIR);
     }
 
     if (not send_http_response(s, http_ok, "", http_contenttype_json)) {
         return false;
     }
 
-    const auto json_str = j.dump();
+    const auto json_str = build_mux_json(mux_json);
 
     ssize_t ret = s.send(json_str.c_str(), json_str.size(), MSG_NOSIGNAL);
     if (ret == -1) {
@@ -854,7 +800,7 @@ bool WebRadioInterface::send_mp3(Socket& s, const std::string& stream)
 
     for (const auto& srv : rx->getServiceList()) {
         if (rx->serviceHasAudioComponent(srv) and
-                (to_hex<4>(srv.serviceId) == stream or
+                (to_hex(srv.serviceId, 4) == stream or
                 (uint32_t)std::stoul(stream) == srv.serviceId)) {
             try {
                 auto& ph = phs.at(srv.serviceId);
@@ -894,7 +840,7 @@ bool WebRadioInterface::send_mp3(Socket& s, const std::string& stream)
 bool WebRadioInterface::send_slide(Socket& s, const std::string& stream)
 {
     for (const auto& wph : phs) {
-        if (to_hex<4>(wph.first) == stream or
+        if (to_hex(wph.first, 4) == stream or
                 (uint32_t)std::stoul(stream) == wph.first) {
             const auto mot = wph.second.getMOT();
 
@@ -920,14 +866,17 @@ bool WebRadioInterface::send_slide(Socket& s, const std::string& stream)
             }
             headers << "\r\n";
 
+            headers << http_nocache;
+
             headers << "Last-Modified: ";
             std::time_t t = chrono::system_clock::to_time_t(mot.time);
             headers << put_time(std::gmtime(&t), "%a, %d %b %Y %T GMT");
             headers << "\r\n";
+
             headers << "\r\n";
             const auto headers_str = headers.str();
             int ret = s.send(headers_str.data(), headers_str.size(), MSG_NOSIGNAL);
-            if (ret == 0) {
+            if (ret == (ssize_t)headers_str.size()) {
                 ret = s.send(mot.data.data(), mot.data.size(), MSG_NOSIGNAL);
             }
 
@@ -1172,10 +1121,10 @@ bool WebRadioInterface::handle_coarse_corrector_post(Socket& s, const std::strin
     cerr << "POST coarse : " << coarseCorrector << endl;
 
     if (coarseCorrector == "0") {
-        rro.disable_coarse_corrector = true;
+        rro.disableCoarseCorrector = true;
     }
     else if (coarseCorrector == "1") {
-        rro.disable_coarse_corrector = false;
+        rro.disableCoarseCorrector = false;
     }
     else {
         string response = http_400;
@@ -1341,22 +1290,24 @@ void WebRadioInterface::handle_phs()
         check_decoders_required();
     }
 
-    if (running) {
-        unique_lock<mutex> lock(rx_mut);
-        ASSERT_RX;
-        for (auto& s : rx->getServiceList()) {
-            const auto sid = s.serviceId;
-            const bool is_decoded = programmes_being_decoded[sid];
-            if (is_decoded) {
-                (void)rx->removeServiceToDecode(s);
+    cerr << "TEARDOWN Cancel all PHs and remove services" << endl;
+    {
+        lock_guard<mutex> lock(rx_mut);
+        for (auto& ph : phs) {
+            ph.second.cancelAll();
+
+            const auto srv = rx->getService(ph.first);
+            if (srv.serviceId != 0) {
+                (void)rx->removeServiceToDecode(srv);
             }
         }
     }
 
-    phs.clear();
-    programmes_being_decoded.clear();
-    carousel_services_available.clear();
-    carousel_services_active.clear();
+    cerr << "TEARDOWN Stop rx" << endl;
+    {
+        unique_lock<mutex> lock(rx_mut);
+        rx->stop();
+    }
 }
 
 #if HAVE_SIGACTION
@@ -1404,6 +1355,38 @@ void WebRadioInterface::serve()
         }
         running_connections = move(still_running_connections);
     }
+
+    cerr << "SERVE No more connections running" << endl;
+
+    running = false;
+    if (programme_handler_thread.joinable()) {
+        programme_handler_thread.join();
+    }
+
+    cerr << "SERVE Wait for all futures to clear" << endl;
+    while (running_connections.size() > 0) {
+        deque<future<bool> > still_running_connections;
+        for (auto& fut : running_connections) {
+            if (fut.valid()) {
+                switch (fut.wait_for(chrono::milliseconds(1))) {
+                    case future_status::deferred:
+                    case future_status::timeout:
+                        still_running_connections.push_back(move(fut));
+                        break;
+                    case future_status::ready:
+                        fut.get();
+                        break;
+                }
+            }
+        }
+        running_connections = move(still_running_connections);
+    }
+
+    cerr << "SERVE clear remaining data structures" << endl;
+    phs.clear();
+    programmes_being_decoded.clear();
+    carousel_services_available.clear();
+    carousel_services_active.clear();
 }
 
 void WebRadioInterface::onSNR(int snr)
