@@ -30,6 +30,7 @@
 #include <QDebug>
 #include <QSettings>
 #include <QQuickStyle>
+#include <QQmlProperty>
 
 #include "gui_helper.h"
 #include "debug_output.h"
@@ -53,10 +54,11 @@ CGUIHelper::CGUIHelper(CRadioController *RadioController, QObject *parent)
     , impulseResponseSeries(nullptr)
 {
     // Add image provider for the MOT slide show
-    motImage = new CMOTImageProvider;
+    motImageProvider = new CMOTImageProvider;
 
     QSettings settings;
     connect(RadioController, &CRadioController::motChanged, this, &CGUIHelper::motUpdate);
+    connect(RadioController, &CRadioController::motReseted, this, &CGUIHelper::motReset);
     connect(RadioController, &CRadioController::showErrorMessage, this, &CGUIHelper::showErrorMessage);
     connect(RadioController, &CRadioController::showInfoMessage, this, &CGUIHelper::showInfoMessage);
 
@@ -100,12 +102,12 @@ CGUIHelper::~CGUIHelper()
     // Avoid segmentation fault if a debug message should be displayed after deleting
     CDebugOutput::setCGUI(nullptr);
 
-    qDebug() << "GUI:" <<  "deleting radioInterface";
+    qDebug() << "GUI:" <<  "Deleting CGUIHelper";
 }
 
 void CGUIHelper::close()
 {
-    qDebug() << "GUI:" <<  "close application";
+    qDebug() << "GUI:" <<  "Close application";
     QApplication::quit();
 }
 
@@ -119,15 +121,10 @@ void CGUIHelper::deviceClosed()
 const QVariantMap CGUIHelper::licenses()
 {
     QVariantMap ret;
-    QFile *File;
     QByteArray InfoContent;
 
     // Set application version
-    InfoContent.append("welle.io " + tr("version") + ": " + QString(CURRENT_VERSION) + "\n");
-    InfoContent.append(tr("Git revision") + ": " + QString(GITHASH) + "\n");
-    InfoContent.append(tr("Build on") + ": " + QString(__TIMESTAMP__) + "\n");
-    InfoContent.append(tr("QT version") + ": " + qVersion() + "\n");
-    InfoContent.append("\n");
+    InfoContent.append(getInfoPage("Versions"));
 
     InfoContent.append("For legal information scroll down, please.\n");
     InfoContent.append("\n");
@@ -135,47 +132,25 @@ const QVariantMap CGUIHelper::licenses()
     // Read AUTHORS
     InfoContent.append("AUTHORS\n");
     InfoContent.append("-------\n");
-    File = new QFile(":/AUTHORS");
-    File->open(QFile::ReadOnly);
-    InfoContent.append(File->readAll());
-    InfoContent.append("\n");
-    delete File;
+    InfoContent.append(getInfoPage("Authors"));
 
     // Read THANKS
     InfoContent.append("THANKS\n");
     InfoContent.append("------\n");
-    File = new QFile(":/THANKS");
-    File->open(QFile::ReadOnly);
-    InfoContent.append(File->readAll());
-    InfoContent.append("\n");
-    delete File;
+    InfoContent.append(getInfoPage("Thanks"));
 
     // Read COPYING
     InfoContent.append("COPYING (GPLv2)\n");
     InfoContent.append("-------\n");
-    File = new QFile(":/COPYING");
-    File->open(QFile::ReadOnly);
-    InfoContent.append(File->readAll());
-    InfoContent.append("\n");
-    delete File;
+    InfoContent.append(getInfoPage("GPL-2"));
 
-    // Read COPYING
     InfoContent.append("COPYING (LGPL-2.1)\n");
     InfoContent.append("-------\n");
-    File = new QFile(":/libs/COPYING.LGPL-2.1");
-    File->open(QFile::ReadOnly);
-    InfoContent.append(File->readAll());
-    InfoContent.append("\n");
-    delete File;
+    InfoContent.append(getInfoPage("LGPL-2.1"));
 
-    // Read COPYING
     InfoContent.append("kiss_fft COPYING (BSD 3-clause)\n");
     InfoContent.append("-------\n");
-    File = new QFile(":/libs/kiss_fft/COPYING");
-    File->open(QFile::ReadOnly);
-    InfoContent.append(File->readAll());
-    InfoContent.append("\n");
-    delete File;
+    InfoContent.append(getInfoPage("BSD-3-Clause"));
 
     // Set graph license content
     ret.insert("FileContent", InfoContent);
@@ -183,14 +158,71 @@ const QVariantMap CGUIHelper::licenses()
     return ret;
 }
 
-void CGUIHelper::motUpdate(QImage MOTImage)
+const QByteArray CGUIHelper::getFileContent(QString filepath)
 {
-    if (MOTImage.isNull()) {
-        MOTImage = QImage(320, 240, QImage::Format_Alpha8);
-        MOTImage.fill(Qt::transparent);
+    QFile *File;
+    QByteArray InfoContent;
+    File = new QFile(filepath);
+    File->open(QFile::ReadOnly);
+    InfoContent.append(File->readAll());
+    InfoContent.append("\n");
+    delete File;
+    return InfoContent;
+}
+
+const QByteArray CGUIHelper::getInfoPage(QString pageName)
+{
+    QByteArray InfoContent;
+
+    if (pageName == "Versions") {
+        // Set application version
+        InfoContent.append(tr("welle.io version") + ": " + QString(CURRENT_VERSION) + "\n");
+        InfoContent.append(tr("Git revision") + ": " + QString(GITHASH) + "\n");
+        QString ts = QString(__TIMESTAMP__).replace("  "," ");
+        QDateTime tsDT = QLocale(QLocale::C).toDateTime(ts, "ddd MMM d hh:mm:ss yyyy");
+        InfoContent.append(tr("Built on") + ": " + tsDT.toString(Qt::ISODate) + "\n");
+        InfoContent.append(tr("QT version") + ": " + qVersion() + "\n");
+        InfoContent.append("\n");
+    } else if (pageName == "Authors") {
+        return getFileContent(":/AUTHORS");
+    } else if (pageName == "Thanks") {
+        return getFileContent(":/THANKS");
+    } else if (pageName == "GPL-2") {
+        return getFileContent(":/COPYING");
+    } else if (pageName == "LGPL-2.1") {
+        return getFileContent(":/libs/COPYING.LGPL-2.1");
+    } else if (pageName == "BSD-3-Clause") {
+       return getFileContent(":/libs/kiss_fft/COPYING");
     }
-    this->motImage->setPixmap(QPixmap::fromImage(MOTImage));
-    emit motChanged();
+
+    return InfoContent;
+}
+
+void CGUIHelper::motUpdate(mot_file_t mot_file)
+{
+    std::clog  << "SLS ContentName: " << mot_file.content_name << std::endl;
+    std::clog  << "catSLS Category: " << std::to_string(mot_file.category) << " SlideID: " << std::to_string(mot_file.slide_id) << std::endl;
+    std::clog  << "catSLS CategoryTitle: " << mot_file.category_title << std::endl;
+    std::clog  << "ClickThroughURL: " << mot_file.click_through_url << std::endl;
+
+    QString pictureName =
+            "/" + QString::number(mot_file.category) +
+            "/" + QString::fromStdString(mot_file.category_title) +
+            "/" + QString::number(mot_file.slide_id) +
+            "/" + QString::fromStdString(mot_file.content_name);
+
+    QByteArray qdata(reinterpret_cast<const char*>(mot_file.data.data()), static_cast<int>(mot_file.data.size()));
+    QImage motImage;
+    motImage.loadFromData(qdata, mot_file.content_sub_type == 0 ? "GIF" : mot_file.content_sub_type == 1 ? "JPEG" : mot_file.content_sub_type == 2 ? "BMP" : "PNG");
+    motImageProvider->setPixmap(QPixmap::fromImage(motImage), pictureName);
+
+    emit motChanged(pictureName, QString::fromStdString(mot_file.category_title), mot_file.category, mot_file.slide_id);
+}
+
+void CGUIHelper::motReset()
+{
+    motImageProvider->clear();
+    emit motReseted();
 }
 
 void CGUIHelper::showErrorMessage(QString Text)
@@ -260,12 +292,21 @@ void CGUIHelper::registerConstellationSeries(QAbstractSeries *series)
 void CGUIHelper::tryHideWindow()
 {
 #ifndef QT_NO_SYSTEMTRAYICON
-    // Hide only if system tray is available otherwise ignore it. Standard Gnome doesn't have a system tray so user would lost the control.
-    if(trayIcon->isSystemTrayAvailable()) {
-        trayIcon->showMessage(QCoreApplication::applicationName(), tr("The program will keep running in the "
-                                           "system tray. To terminate the program, "
-                                           "choose <b>Quit</b> in the context menu "
-                                           "of the system tray entry."), QIcon(":/icon.png"), 5000);
+    QSettings settings;
+    int count = settings.value("hideWindowTrayMessageDisplayCount",0).toInt();
+
+    // Hide only if system tray is available otherwise ignore it. Standard Gnome doesn't have a system tray so user would lose the control.
+    if(trayIcon->isSystemTrayAvailable() && count < 4) {
+        trayIcon->showMessage(QCoreApplication::applicationName(),
+                              tr("The program will keep running in the "
+                              "system tray. To terminate the program, "
+                              "choose \"%1\" in the context menu "
+                              "of the system tray entry.").arg(
+                                //: "Quit" translation should be the same as the one of system tray
+                                tr("Quit")
+                              ),
+                              QIcon(":/icon.png"), 5000);
+        settings.setValue("hideWindowTrayMessageDisplayCount", count+1);
         emit minimizeWindow();
     }
 #endif
@@ -484,6 +525,11 @@ void CGUIHelper::updateConstellation()
     */
 }
 
+void CGUIHelper::saveMotImages()
+{
+    motImageProvider->saveAll();
+}
+
 void CGUIHelper::openAutoDevice()
 {
     CDeviceID deviceId;
@@ -491,6 +537,11 @@ void CGUIHelper::openAutoDevice()
     emit newDeviceId(static_cast<int>(deviceId));
 }
 
+void CGUIHelper::openNull()
+{
+    radioController->openDevice(CDeviceID::NULLDEVICE);
+}
+
 void CGUIHelper::openAirspy()
 {
     radioController->openDevice(CDeviceID::AIRSPY);
@@ -535,9 +586,9 @@ void CGUIHelper::setClockSourceSoapySdr(QString text)
     radioController->setDeviceParam("SoapySDRClockSource", text);
 }
 
-void CGUIHelper::openRtlTcp(QString IpAddress, int IpPort, bool force)
+void CGUIHelper::openRtlTcp(QString serverAddress, int IpPort, bool force)
 {
-    radioController->openDevice(CDeviceID::RTL_TCP, force, IpAddress, IpPort);
+    radioController->openDevice(CDeviceID::RTL_TCP, force, serverAddress, IpPort);
 }
 
 void CGUIHelper::openRawFile(QString fileFormat)
@@ -553,11 +604,13 @@ void CGUIHelper::openRawFile(QString fileFormat)
     // Open file dialog
     activityResultReceiver = new FileActivityResultReceiver(this, fileFormat);
     QtAndroid::startActivity( intent.object<jobject>(), 12, activityResultReceiver);
+#else
+    (void) fileFormat;
 #endif
 }
 
 void CGUIHelper::openRawFile(QString filename, QString fileFormat)
-{   
+{
     radioController->openDevice(CDeviceID::RAWFILE, true, filename, fileFormat);
 }
 
@@ -572,7 +625,7 @@ void CGUIHelper::setTranslator(QTranslator *translator)
     this->translator = translator;
 }
 
-QTranslator* CGUIHelper::loadTranslationFile(QTranslator *translator, QString Language)
+QString CGUIHelper::mapToLanguage(QString Language)
 {
     if(Language == "auto")
     {
@@ -596,34 +649,50 @@ QTranslator* CGUIHelper::loadTranslationFile(QTranslator *translator, QString La
 
     // Set new language
     qDebug() << "main:" <<  "Set language" << Language;
-    bool isTranslation = translator->load(QString(":/i18n/") + Language);
+    return Language;
+}
 
-    if(!isTranslation)
+bool CGUIHelper::loadTranslationFile(QTranslator *translator, QString Language)
+{
+    bool isLoaded = translator->load(QString(":/i18n/") + Language);
+
+    if(!isLoaded)
     {
         qDebug() << "main:" <<  "Error while loading language" << Language << "use untranslated text (ie. English)";
     }
 
-    return translator;  
+    return isLoaded;
 }
 
 void CGUIHelper::updateTranslator(QString Language, QObject *obj)
 {
-    translator = loadTranslationFile(translator, Language);
+    QString lang = mapToLanguage(Language);
 
-    translateGUI(Language, obj);
+    // Set locale e.g. time formarts
+    QLocale curLocale(QLocale((const QString&)lang));
+    QLocale::setDefault(curLocale);
+
+    loadTranslationFile(translator, lang);
+    translateGUI(obj);
 }
 
-void CGUIHelper::translateGUI(QString Language, QObject *obj)
+void CGUIHelper::translateGUI(QObject *obj)
 {
-    // Set locale e.g. time formarts
-    QLocale curLocale(QLocale((const QString&)Language));
-    QLocale::setDefault(curLocale);
+    // Save previous width & height
+    // (because they are reset by the call to retranslate())
+    QVariant width = QQmlProperty::read(obj, "width");
+    QVariant height = QQmlProperty::read(obj, "height");
 
     // Start translation of GUI
     QQmlContext *currentContext = QQmlEngine::contextForObject(obj);
     QQmlEngine *engine = currentContext->engine();
     engine->retranslate();
 
+    // Restore previous width & height
+    // (because they are reset by the call to retranslate())
+    QQmlProperty::write(obj, "width", width);
+    QQmlProperty::write(obj, "height", height);
+
     // Start translation of non-QML GUI
 #ifndef QT_NO_SYSTEMTRAYICON
     minimizeAction->setText(tr("Mi&nimize"));
@@ -631,6 +700,8 @@ void CGUIHelper::translateGUI(QString Language, QObject *obj)
     restoreAction->setText(tr("&Restore"));
     quitAction->setText(tr("&Quit"));
 #endif
+
+    emit translationFinished();
 }
 
 #ifdef __ANDROID__
@@ -683,7 +754,7 @@ QString CGUIHelper::getQQStyleToLoad(QString styleNameArg)  // Static
 
 const QStringList CGUIHelper::qQStyleComboList()
 {
-    if ( !m_comboList.isEmpty() ) 
+    if ( !m_comboList.isEmpty() )
         return m_comboList;
 
     m_comboList = QQuickStyle::availableStyles();
