@@ -74,11 +74,13 @@ int main(int argc, char** argv)
 
     //Initialise translation
     QTranslator *translator = new QTranslator;
-    translator = CGUIHelper::loadTranslationFile(translator, "auto");
+    QString lang = CGUIHelper::mapToLanguage("auto");
+    CGUIHelper::loadTranslationFile(translator, lang);
     QCoreApplication::installTranslator(translator);
 
-    // Register waterfall diagram
+    // Register custiom types
     qmlRegisterType<WaterfallItem>("io.welle", 1, 0, "Waterfall");
+    qRegisterMetaType<mot_file_t>("mot_file_t");
 
     // Set icon path
     QStringList themePaths;
@@ -138,12 +140,10 @@ int main(int argc, char** argv)
     settings.setValue("version", QString(CURRENT_VERSION));
 
     // Should we play the last station we have listened to previously?
-    if( settings.value("enableLastPlayedStationState", false).toBool() ) {
-
-        QStringList lastStation = settings.value("lastchannel").toStringList();
-        if( lastStation.count() == 2 )
-            radioController.setAutoPlay(lastStation[1], lastStation[0]);
-    }
+    bool isAutoPlay = settings.value("enableLastPlayedStationState", false).toBool();
+    QStringList lastStation = settings.value("lastchannel").toStringList();
+    if( lastStation.count() == 2 )
+        radioController.setAutoPlay(isAutoPlay, lastStation[1], lastStation[0]);
 
     // Load mandatory driver arguments to init input device
     radioController.setDeviceParam("SoapySDRDriverArgs", settings.value("soapyDriverArgs","").toString());
@@ -165,11 +165,15 @@ int main(int argc, char** argv)
     engine.load(QUrl("qrc:/QML/MainView.qml"));
 
     // Add MOT slideshow provider
-    engine.addImageProvider(QLatin1String("motslideshow"), guiHelper.motImage);
+    engine.addImageProvider(QLatin1String("SLS"), guiHelper.motImageProvider);
 
     // Run application
     app.exec();
 
+    // Disconnect all signals and slots
+    guiHelper.disconnect();
+    radioController.disconnect();
+
     qDebug() << "main:" <<  "Application closed";
 
     return 0;
