@@ -107,6 +107,12 @@ CRadioController::CRadioController(QVariantMap& commandLineOptions, QObject *par
             this, &CRadioController::displayDateTime);
 }
 
+CRadioController::~CRadioController()
+{
+    closeDevice();
+    qDebug() << "RadioController:" << "Deleting CRadioController";
+}
+
 void CRadioController::closeDevice()
 {
     qDebug() << "RadioController:" << "Close device";
@@ -131,7 +137,7 @@ CDeviceID CRadioController::openDevice(CDeviceID deviceId, bool force, QVariant
         if (device->getID() == CDeviceID::RTL_TCP) {
             CRTL_TCP_Client* RTL_TCP_Client = static_cast<CRTL_TCP_Client*>(device.get());
 
-            RTL_TCP_Client->setIP(param1.toString().toStdString());
+            RTL_TCP_Client->setServerAddress(param1.toString().toStdString());
             RTL_TCP_Client->setPort(param2.toInt());
         }
 
@@ -185,6 +191,8 @@ void CRadioController::setDeviceParam(QString param, int value)
 void CRadioController::setDeviceParam(QString param, QString value)
 {
     DeviceParam dp;
+    bool deviceParamChanged = false;
+
     if (param == "SoapySDRAntenna") {
         dp = DeviceParam::SoapySDRAntenna;
     }
@@ -200,10 +208,16 @@ void CRadioController::setDeviceParam(QString param, QString value)
     }
 
     std::string v = value.toStdString();
-    deviceParametersString[dp] = v;
 
-    if (device) {
+    if (deviceParametersString[dp] != v) {
+        deviceParamChanged = true;
+        deviceParametersString[dp] = v;
+    }
+
+    if (device && deviceParamChanged) {
         device->setDeviceParam(dp, v);
+        if (dp == DeviceParam::SoapySDRDriverArgs)
+            openDevice(CDeviceID::SOAPYSDR,1);
     }
 }
 
@@ -227,8 +241,9 @@ void CRadioController::play(QString channel, QString title, quint32 service)
     setChannel(channel, false);
     setService(service);
 
+    currentLastChannel = QStringList() << serialise_serviceid(service) << channel;
     QSettings settings;
-    settings.setValue("lastchannel", QStringList() << serialise_serviceid(service) << channel);
+    settings.setValue("lastchannel", currentLastChannel);
 }
 
 void CRadioController::stop()
@@ -247,6 +262,7 @@ void CRadioController::setService(uint32_t service, bool force)
 {
     if (currentService != service or force) {
         currentService = service;
+        autoService = service;
         emit stationChanged();
 
         // Wait if we found the station inside the signal
@@ -262,16 +278,16 @@ void CRadioController::setService(uint32_t service, bool force)
         currentText = "";
         emit textChanged();
 
-        motImage.loadFromData(nullptr, 0);
-        emit motChanged(motImage);
+        emit motReseted();
     }
 }
 
-void CRadioController::setAutoPlay(QString channel, QString service)
+void CRadioController::setAutoPlay(bool isAutoPlayValue, QString channel, QString service)
 {
-    isAutoPlay = true;
+    isAutoPlay = isAutoPlayValue;
     autoChannel = channel;
     autoService = deserialise_serviceid(service.toStdString().c_str());
+    currentLastChannel = QStringList() << service << channel;
 }
 
 void CRadioController::setVolume(qreal Volume)
@@ -286,12 +302,14 @@ void CRadioController::setChannel(QString Channel, bool isScan, bool Force)
     if (currentChannel != Channel || Force == true) {
         if (device && device->getID() == CDeviceID::RAWFILE) {
             currentChannel = "File";
+            autoChannel = currentChannel;
             currentEId = 0;
             currentEnsembleLabel = "";
             currentFrequency = 0;
         }
         else { // A real device
             currentChannel = Channel;
+            autoChannel = currentChannel;
             currentEId = 0;
             currentEnsembleLabel = "";
 
@@ -340,9 +358,7 @@ void CRadioController::setManualChannel(QString Channel)
     currentText = "";
     emit textChanged();
 
-    // Clear MOT
-    motImage.loadFromData(nullptr, 0);
-    emit motChanged(motImage);
+    emit motReseted();
 
     // Switch channel
     setChannel(Channel, false, true);
@@ -400,6 +416,8 @@ void CRadioController::stopScan(void)
 
     isChannelScan = false;
     emit scanStopped();
+
+    stop();
 }
 
 void CRadioController::setAGC(bool isAGC)
@@ -423,7 +441,7 @@ void CRadioController::setAGC(bool isAGC)
 
 void CRadioController::disableCoarseCorrector(bool disable)
 {
-    rro.disable_coarse_corrector = disable;
+    rro.disableCoarseCorrector = disable;
     if (radioReceiver) {
         radioReceiver->setReceiverOptions(rro);
     }
@@ -631,8 +649,7 @@ void CRadioController::resetTechnicalData(void)
     rsErrors = 0;
     aaErrors = 0;
 
-    motImage.loadFromData(nullptr, 0);
-    emit motChanged(motImage);
+    emit motReseted();
 }
 
 void CRadioController::deviceRestart()
@@ -770,10 +787,10 @@ void CRadioController::stationTimerTimeout()
                         qDebug() << "Selecting service failed";
                     }
                     else {
-                        currentStationType = QCoreApplication::translate("DABConstants",(DABConstants::getProgramTypeName(s.programType)));
+                        currentStationType = DABConstants::getProgramTypeName(s.programType);
                         emit stationTypChanged();
 
-                        currentLanguageType = QCoreApplication::translate("DABConstants",(DABConstants::getLanguageName(s.language)));
+                        currentLanguageType = DABConstants::getLanguageName(s.language);
                         emit languageTypeChanged();
 
                         bitRate = subch.bitrate();
@@ -1032,15 +1049,17 @@ void CRadioController::onNewDynamicLabel(const std::string& label)
     }
 }
 
-void CRadioController::onMOT(const std::vector<uint8_t>& Data, int subtype)
+void CRadioController::onMOT(const mot_file_t& mot_file)
 {
-    QByteArray qdata(reinterpret_cast<const char*>(Data.data()), static_cast<int>(Data.size()));
-    motImage.loadFromData(qdata, subtype == 0 ? "GIF" : subtype == 1 ? "JPEG" : subtype == 2 ? "BMP" : "PNG");
-
-    emit motChanged(motImage);
+    emit motChanged(mot_file);
 }
 
 void CRadioController::onPADLengthError(size_t announced_xpad_len, size_t xpad_len)
 {
     qDebug() << "X-PAD length mismatch, expected:" << announced_xpad_len << " effective:" << xpad_len;
 }
+
+void CRadioController::onInputFailure()
+{
+    stop();
+}
