@@ -38,6 +38,7 @@
 #include <QDateTime>
 #include <QImage>
 #include <QVariantMap>
+#include <QFile>
 #include <mutex>
 #include <list>
 
@@ -80,9 +81,9 @@ class CRadioController :
     Q_PROPERTY(int gain MEMBER currentManualGain WRITE setGain NOTIFY gainChanged)
     Q_PROPERTY(qreal volume MEMBER currentVolume WRITE setVolume NOTIFY volumeChanged)
     Q_PROPERTY(QString errorMsg MEMBER errorMsg NOTIFY showErrorMessage)
-    Q_PROPERTY(QImage mot MEMBER motImage NOTIFY motChanged)
 
     Q_PROPERTY(QString channel MEMBER currentChannel NOTIFY channelChanged)
+    Q_PROPERTY(QStringList lastChannel MEMBER currentLastChannel NOTIFY lastChannelChanged)
     Q_PROPERTY(QString ensemble MEMBER currentEnsembleLabel NOTIFY ensembleChanged)
     Q_PROPERTY(int frequency MEMBER currentFrequency NOTIFY frequencyChanged)
     Q_PROPERTY(quint32 service MEMBER currentService NOTIFY stationChanged)
@@ -93,6 +94,10 @@ class CRadioController :
 
 public:
     CRadioController(QVariantMap &commandLineOptions, QObject* parent = nullptr);
+    ~CRadioController();
+    CRadioController(const CRadioController&) = delete;
+    void operator=(const CRadioController&) = delete;
+
     void closeDevice();
     CDeviceID openDevice(CDeviceID deviceId, bool force = false, QVariant param1 = QVariant(), QVariant param2 = QVariant());
     CDeviceID openDevice();
@@ -106,7 +111,7 @@ public:
     Q_INVOKABLE void setManualChannel(QString Channel);
     Q_INVOKABLE void startScan(void);
     Q_INVOKABLE void stopScan(void);
-    void setAutoPlay(QString channel, QString serviceid_as_string);
+    Q_INVOKABLE void setAutoPlay(bool isAutoPlayValue, QString channel, QString serviceid_as_string);
     Q_INVOKABLE void setVolume(qreal volume);
     Q_INVOKABLE void setAGC(bool isAGC);
     Q_INVOKABLE void disableCoarseCorrector(bool disable);
@@ -131,7 +136,7 @@ public:
     virtual void onRsErrors(bool uncorrectedErrors, int numCorrectedErrors) override;
     virtual void onAacErrors(int aacErrors) override;
     virtual void onNewDynamicLabel(const std::string& label) override;
-    virtual void onMOT(const std::vector<uint8_t>& data, int subtype) override;
+    virtual void onMOT(const mot_file_t& mot_file) override;
     virtual void onPADLengthError(size_t announced_xpad_len, size_t xpad_len) override;
     virtual void onSNR(int snr) override;
     virtual void onFrequencyCorrectorChange(int fine, int coarse) override;
@@ -147,6 +152,7 @@ public:
     virtual void onNewNullSymbol(std::vector<DSPCOMPLEX>&& data) override;
     virtual void onTIIMeasurement(tii_measurement_t&& m) override;
     virtual void onMessage(message_level_t level, const std::string& text, const std::string& text2 = std::string()) override;
+    virtual void onInputFailure(void) override;
 
 private:
     void initialise(void);
@@ -187,9 +193,9 @@ private:
     int aaErrors = 0;
     int gainCount = 0;
     int stationCount = 0;
-    QImage motImage;
 
     QString currentChannel;
+    QStringList currentLastChannel;
     std::list<uint32_t> pendingLabels;
     QString currentEnsembleLabel;
     uint16_t currentEId;
@@ -264,9 +270,11 @@ signals:
     void gainValueChanged(float);
     void gainChanged(int);
     void volumeChanged(qreal);
-    void motChanged(QImage MOTImage);
+    void motChanged(mot_file_t);
+    void motReseted(void);
 
     void channelChanged();
+    void lastChannelChanged();
     void ensembleChanged();
     void frequencyChanged();
     void stationChanged();
